@@ -12,25 +12,18 @@ rita_result <- function(data,
                         from = NULL,
                         to = NULL,
                         states = NULL,
-                        facilities = NULL
-) {
-
-
-
+                        facilities = NULL) {
   states <- states %||% unique(data$facility_state)
 
   facilities <- facilities %||% unique(subset(data, facility_state %in% states)$facility)
 
-  validate_recent(data, from, to , states, facilities)
+  validate_recent(data, from, to, states, facilities)
 
   get_rita(data, from, to, states, facilities)
-
-
 }
 
 
-get_rita <-  function(data, from, to, states, facilities) {
-
+get_rita <- function(data, from, to, states, facilities) {
   dt <- dplyr::filter(
     data,
     recency_interpretation == "Recent",
@@ -48,14 +41,13 @@ get_rita <-  function(data, from, to, states, facilities) {
     )
   }
 
-  if(!is.null(to)) {
+  if (!is.null(to)) {
     dt <- dplyr::filter(
       dt, date_of_viral_load_result <= lubridate::ymd(to)
     )
   }
 
   return(dt)
-
 }
 
 
@@ -63,4 +55,3 @@ get_rita <-  function(data, from, to, states, facilities) {
 utils::globalVariables(
   c("recency_interpretation", "date_of_viral_load_result", "viral_load_result", "facility_state")
 )
-
