@@ -8,28 +8,23 @@
 #' @examples
 #' ## Line-list RTRI recent persons for 'Arewa' state for the first quarter of 2021
 #' rtri_recent(recency_example, states = "Arewa", from = "2021-01-01", to = "2021-03-31")
-
+#'
 rtri_recent <- function(data,
-                     from = NULL,
-                     to = NULL,
-                     states = NULL,
-                     facilities = NULL
-) {
-
+                        from = NULL,
+                        to = NULL,
+                        states = NULL,
+                        facilities = NULL) {
   states <- states %||% unique(data$facility_state)
 
   facilities <- facilities %||% unique(subset(data, facility_state %in% states)$facility)
 
-  validate_recent(data, from, to , states, facilities)
+  validate_recent(data, from, to, states, facilities)
 
   get_rtri_recent(data, from, to, states, facilities)
-
-
 }
 
 
-get_rtri_recent <-  function(data, from, to, states, facilities) {
-
+get_rtri_recent <- function(data, from, to, states, facilities) {
   dt <- dplyr::filter(
     data,
     recency_interpretation == "Recent",
@@ -44,7 +39,7 @@ get_rtri_recent <-  function(data, from, to, states, facilities) {
     )
   }
 
-  if(!is.null(to)) {
+  if (!is.null(to)) {
     dt <- dplyr::filter(
       dt, recency_test_date <= lubridate::ymd(to)
     )
@@ -58,4 +53,3 @@ get_rtri_recent <-  function(data, from, to, states, facilities) {
 utils::globalVariables(
   c("recency_test_date", "recency_interpretation")
 )
-
