@@ -32,19 +32,19 @@
 tx_curr <- function(data,
                     states = NULL,
                     facilities = NULL,
-                    status = "calculated") {
-
+                    status = "default",
+                    remove_duplicates = FALSE) {
   states <- states %||% unique(data$state)
 
   facilities <- facilities %||% unique(subset(data, state %in% states)$facility)
 
-  validate_curr(data, states, facilities, status)
+  validate_curr(data, states, facilities, status, remove_duplicates)
 
-  get_tx_curr(data, states, facilities, status)
+  get_tx_curr(data, states, facilities, status, remove_duplicates)
 }
 
 
-validate_curr <- function(data, states, facilities, status) {
+validate_curr <- function(data, states, facilities, status, remove_duplicates) {
   if (!all(states %in% unique(data$state))) {
     rlang::abort("state(s) is/are not contained in the supplied data. Check the spelling and/or case.")
   }
@@ -57,18 +57,22 @@ validate_curr <- function(data, states, facilities, status) {
   if (!status %in% c("default", "calculated")) {
     rlang::abort("`status` can only be one of 'default' or 'calculated'. Check that you did not mispell, include CAPS or forget to quotation marks!")
   }
+
+  if (!is.logical(remove_duplicates)) {
+    rlang::abort("The `remove_duplicates` argument is a logical variable and can only be set to `TRUE` or `FALSE`")
+  }
 }
 
 get_tx_curr <- function(data,
                         states,
                         facilities,
-                        status) {
-  switch(status,
+                        status,
+                        remove_duplicates) {
+  df <- switch(status,
     "calculated" = dplyr::filter(
       data,
       current_status == "Active",
       !patient_has_died %in% TRUE,
-      !patient_transferred_out %in% TRUE,
       state %in% states,
       facility %in% facilities
     ),
@@ -76,15 +80,23 @@ get_tx_curr <- function(data,
       data,
       current_status_28_days == "Active",
       !patient_has_died %in% TRUE,
-      !patient_transferred_out %in% TRUE,
       state %in% states,
       facility %in% facilities
     )
   )
+
+
+  if (remove_duplicates) {
+    df <- dplyr::distinct(df, facility, patient_identifier, .keep_all = TRUE)
+  }
+
+  return(df)
 }
 
 utils::globalVariables(
-  c("current_status",
+  c(
+    "current_status",
     "patient_has_died",
-    "patient_transferred_out")
+    "patient_transferred_out"
+  )
 )
