@@ -24,21 +24,19 @@ tx_regimen <- function(data,
                        age_band = NULL,
                        states = NULL,
                        facilities = NULL,
-                       status = "calculated") {
-
+                       status = "default",
+                       remove_duplicates = FALSE) {
   states <- states %||% unique(data$state)
 
   facilities <- facilities %||% unique(subset(data, state %in% states)$facility)
 
-  validate_regimen(data, age_band, states, facilities, status)
-
-  get_tx_regimen(data, age_band, states, facilities, status)
-
+  validate_regimen(data, age_band, states, facilities, status, remove_duplicates)
 
+  get_tx_regimen(data, age_band, states, facilities, status, remove_duplicates)
 }
 
 
-validate_regimen <- function(data, age_band, states, facilities, status) {
+validate_regimen <- function(data, age_band, states, facilities, status, remove_duplicates) {
   if (!rlang::is_double(age_band) && !rlang::is_null(age_band)) {
     rlang::abort("age_band is not of the class numeric. Did you quote any of the values?")
   }
@@ -59,63 +57,70 @@ validate_regimen <- function(data, age_band, states, facilities, status) {
   if (!status %in% c("default", "calculated")) {
     rlang::abort("`status` can only be one of 'default' or 'calculated'. Check that you did not mispell, include CAPS or forget to quotation marks!")
   }
+
+  if (!is.logical(remove_duplicates)) {
+    rlang::abort("The `remove_duplicates` argument is a logical variable and can only be set to `TRUE` or `FALSE`")
+  }
 }
 
 
-get_tx_regimen <- function(data, age_band, states, facilities, status) {
-
+get_tx_regimen <- function(data, age_band, states, facilities, status, remove_duplicates) {
   age_range <- c(0, 150)
 
-  switch(status,
-         "calculated" = dplyr::filter(
-           data,
-           current_status == "Active",
-           !patient_has_died %in% TRUE,
-           !patient_transferred_out %in% TRUE,
-           dplyr::if_else(
-             current_age <= 3,
-             last_regimen %in% c(
-               "ABC-3TC-LPV/r",
-               "AZT-3TC-LPV/r"
-             ),
-             last_regimen %in% c(
-               "ABC-3TC-DTG",
-               "TDF-3TC-DTG"
-             )
-           ),
-           dplyr::between(
-             current_age,
-             age_band[[1]] %||% age_range[[1]],
-             age_band[[2]] %||% age_range[[2]]
-           ),
-           state %in% states,
-           facility %in% facilities
-         ),
-         "default" = dplyr::filter(
-           data,
-           current_status_28_days == "Active",
-           !patient_has_died %in% TRUE,
-           !patient_transferred_out %in% TRUE,
-           dplyr::if_else(
-             current_age <= 3,
-             last_regimen %in% c(
-               "ABC-3TC-LPV/r",
-               "AZT-3TC-LPV/r"
-             ),
-             last_regimen %in% c(
-               "ABC-3TC-DTG",
-               "TDF-3TC-DTG"
-             )
-           ),
-           dplyr::between(
-             current_age,
-             age_band[[1]] %||% age_range[[1]],
-             age_band[[2]] %||% age_range[[2]]
-           ),
-           state %in% states,
-           facility %in% facilities
-         )
+  df <- switch(status,
+    "calculated" = dplyr::filter(
+      data,
+      current_status == "Active",
+      !patient_has_died %in% TRUE,
+      dplyr::if_else(
+        current_age <= 3,
+        last_regimen %in% c(
+          "ABC-3TC-LPV/r",
+          "AZT-3TC-LPV/r"
+        ),
+        last_regimen %in% c(
+          "ABC-3TC-DTG",
+          "TDF-3TC-DTG"
+        )
+      ),
+      dplyr::between(
+        current_age,
+        age_band[[1]] %||% age_range[[1]],
+        age_band[[2]] %||% age_range[[2]]
+      ),
+      state %in% states,
+      facility %in% facilities
+    ),
+    "default" = dplyr::filter(
+      data,
+      current_status_28_days == "Active",
+      !patient_has_died %in% TRUE,
+      dplyr::if_else(
+        current_age <= 3,
+        last_regimen %in% c(
+          "ABC-3TC-LPV/r",
+          "AZT-3TC-LPV/r"
+        ),
+        last_regimen %in% c(
+          "ABC-3TC-DTG",
+          "TDF-3TC-DTG"
+        )
+      ),
+      dplyr::between(
+        current_age,
+        age_band[[1]] %||% age_range[[1]],
+        age_band[[2]] %||% age_range[[2]]
+      ),
+      state %in% states,
+      facility %in% facilities
+    )
   )
+
+  if (remove_duplicates) {
+    df <- dplyr::distinct(df, facility, patient_identifier, .keep_all = TRUE)
+  }
+
+  return(df)
 }
 
 utils::globalVariables(c(
