@@ -30,16 +30,15 @@ tx_rtt <- function(new_data,
                    old_data,
                    states = NULL,
                    facilities = NULL,
-                   status = "calculated") {
-
-
+                   status = "default",
+                   remove_duplicates = FALSE) {
   states <- states %||% unique(new_data$state)
 
   facilities <- facilities %||% unique(subset(new_data, state %in% states)$facility)
 
-  validate_rtt(new_data, old_data, states, facilities, status)
+  validate_rtt(new_data, old_data, states, facilities, status, remove_duplicates)
 
-  get_tx_rtt(new_data, old_data, states, facilities, status)
+  get_tx_rtt(new_data, old_data, states, facilities, status, remove_duplicates)
 }
 
 
@@ -48,7 +47,8 @@ validate_rtt <- function(new_data,
                          old_data,
                          states,
                          facilities,
-                         status) {
+                         status,
+                         remove_duplicates) {
   if (!all(states %in% unique(new_data$state))) {
     rlang::warn("state(s) is/are not contained in the supplied data. Check the spelling and/or case.")
   }
@@ -61,33 +61,34 @@ validate_rtt <- function(new_data,
   if (!status %in% c("default", "calculated")) {
     rlang::abort("`status` can only be one of 'default' or 'calculated'. Check that you did not mispell, include CAPS or forget to quotation marks!")
   }
+
+  if (!is.logical(remove_duplicates)) {
+    rlang::abort("The `remove_duplicates` argument is a logical variable and can only be set to `TRUE` or `FALSE`")
+  }
 }
 
 
 
-get_tx_rtt <- function(new_data, old_data, states, facilities, status) {
+get_tx_rtt <- function(new_data, old_data, states, facilities, status, remove_duplicates) {
   losses <- switch(status,
     "calculated" = dplyr::filter(
       old_data,
       current_status == "Inactive",
-      !patient_has_died %in% TRUE,
-      !patient_transferred_out %in% TRUE,
+      !patient_has_died %in% TRUE
     ),
     "default" = dplyr::filter(
       old_data,
       current_status_28_days == "Inactive",
-      !patient_has_died %in% TRUE,
-      !patient_transferred_out %in% TRUE,
+      !patient_has_died %in% TRUE
     )
   )
 
-  switch(status,
+  df <- switch(status,
     "calculated" = dplyr::filter(
       new_data,
       current_status == "Active",
       patient_identifier %in% losses$patient_identifier,
       !patient_has_died %in% TRUE,
-      !patient_transferred_out %in% TRUE,
       state %in% states,
       facility %in% facilities
     ),
@@ -96,11 +97,16 @@ get_tx_rtt <- function(new_data, old_data, states, facilities, status) {
       current_status_28_days == "Active",
       patient_identifier %in% losses$patient_identifier,
       !patient_has_died %in% TRUE,
-      !patient_transferred_out %in% TRUE,
       state %in% states,
       facility %in% facilities
     )
   )
+
+  if (remove_duplicates) {
+    df <- dplyr::distinct(df, facility, patient_identifier, .keep_all = TRUE)
+  }
+
+  return(df)
 }
 
 
