@@ -4,8 +4,9 @@ test_that("disaggregation works", {
     {
       ndr_example %>%
         tx_curr() %>%
-        dplyr::count(ip, state, sex, .drop = TRUE) %>%
-        dplyr::mutate(sex = dplyr::recode_factor(sex, "F" = "Female", "M" = "Male")) %>%
+        dplyr::count(ip, state, sex, .drop = FALSE) %>%
+        dplyr::mutate(sex = dplyr::recode_factor(sex, "F" = "Female", "M" = "Male", .default = "unknown")) %>%
+        dplyr::count(ip, state, sex, wt = n, .drop = FALSE) %>%
         tidyr::pivot_wider(names_from = "sex", values_from = "n") %>%
         janitor::adorn_totals(where = "row") %>%
         tibble::as_tibble()
